summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/losparam.h
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/losparam.h')
-rw-r--r--crawl-ref/source/losparam.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/crawl-ref/source/losparam.h b/crawl-ref/source/losparam.h
index 1d6b579565..69e043e5fb 100644
--- a/crawl-ref/source/losparam.h
+++ b/crawl-ref/source/losparam.h
@@ -24,10 +24,11 @@ struct los_param
{
virtual ~los_param() {}
- // Whether the translated coordinate lies in the map (including boundary)
- virtual bool map_bounds(const coord_def& p) const = 0;
+ // Whether the translated coordinate lies within the map
+ // (including boundary) and within the LOS area
+ virtual bool los_bounds(const coord_def& p) const = 0;
- // appearance(p) will be copied to show(p) for visible p.
+ // appearance(p) will be copied to show(sh_o+p) for visible p.
virtual unsigned appearance(const coord_def& p) const = 0;
virtual opacity_type opacity(const coord_def& p) const = 0;
@@ -42,7 +43,7 @@ struct los_param_trans : los_param
coord_def trans(const coord_def& p) const;
- bool map_bounds(const coord_def& p) const;
+ bool los_bounds(const coord_def& p) const;
};
// Everything is visible.